pub struct OccupiedEntry<'a, K, V, P>{ /* private fields */ }Expand description
An entry for a mapping that already exists in the map.
Implementations
Sourceimpl<'a, K, V, P> OccupiedEntry<'a, K, V, P>
impl<'a, K, V, P> OccupiedEntry<'a, K, V, P>
Sourcepub fn remove_entry(self) -> (K, V)
pub fn remove_entry(self) -> (K, V)
Remove this entry from the map and return the removed mapping.